@@ -38,7 +38,7 @@ file from passing.
 
 =head1 SYNOPSIS
 
-    use Test2 qw/context/;
+    use Test2::API qw/context/;
     use Test2::Event::Exception;
 
     my $ctx = context();
