@@ -5,14 +5,14 @@ use warnings;
 use Carp qw/confess longmess/;
 use Test2::Util::HashBase qw{no_fatal};
 
-use Test2::Global();
+use Test2::API qw/test2_ipc_add_driver/;
 
 my %ADDED;
 sub import {
     my $class = shift;
     return if $class eq __PACKAGE__;
     return if $ADDED{$class}++;
-    Test2::Global::test2_ipc_add_driver($class);
+    test2_ipc_add_driver($class);
 }
 
 for my $meth (qw/send cull add_hub drop_hub waiting is_viable/) {
